@@ -32,7 +32,7 @@ Lingua::Jspell - Perl interface to the Jspell morphological analyser.
 
 =cut
 
-our $VERSION = '1.97';
+our $VERSION = '1.98';
 our $JSPELL;
 our $JSPELLLIB;
 our $MODE = { nm => "af", flags => 0 };
@@ -525,12 +525,21 @@ first Feature Structure Pattern.
 
    if (verif( $pattern, $feature) )  { ... }
 
+Use a value of undef, or an empty string, in the pattern, to force that key not to exist:
+
+   if (verif( { FSEM => undef }, $feature)) { .. }
+
 =cut
 
 sub verif {
-    my ($a, $b) = @_;
-    for (keys %$a) {
-        return 0 if (!defined($b->{$_}) || $a->{$_} ne $b->{$_});
+    my ($patt, $b) = @_;
+    for (keys %$patt) {
+        if (!defined($patt->{$_}) || $patt->{$_} eq "") {
+            return 0 if exists $b->{$_};
+        }
+        else {
+            return 0 if (!defined($b->{$_}) || $patt->{$_} ne $b->{$_});
+        }
     }
     return 1;
 }
